Module rocketjson_data::api::response [−][src]
Response
ApiResponse is returned by enpoints to achieve a Json Response
Structs
Is returned by enpoints to achieve a Json Response
ApiResponse is returned by enpoints to achieve a Json Response
Is returned by enpoints to achieve a Json Response